package es.bisite.wilssc;


import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.view.MotionEvent;
import it.sephiroth.android.library.imagezoom.ImageViewTouch;;

//===============================================================
public class BluePinImageView extends ImageViewTouch
//===============================================================
{
	Bitmap bluePin;
	Point pinPosition;
	Point userPosition;
	
	List<PositionRead> points;
	List<Point> midPoints;
	
	float scaleFactor;
	Paint _paint;
	
	Paint _paintLine;
	Paint _paintMidPoints;
	Paint _paintArea;
	Paint _paintPrecision;
	
	final static int CIRCLE_RADIUS = 6 ;
	final static int POINT_AREA = 7 ;
	
	//===============================================================
	public BluePinImageView( Context context, AttributeSet attrs ) 
	//===============================================================
	{
		super( context, attrs );
        this.Reset();
		this._paint=new Paint(Paint.ANTI_ALIAS_FLAG);
		this._paint.setColor(Color.RED);
		this._paintLine=new Paint(Paint.ANTI_ALIAS_FLAG);
		this._paintLine.setColor(Color.RED);
		this._paintMidPoints=new Paint(Paint.ANTI_ALIAS_FLAG);
		this._paintMidPoints.setColor(Color.BLUE);
		this._paintArea=new Paint(Paint.ANTI_ALIAS_FLAG);
		this._paintArea.setColor(Color.CYAN);
		this._paintArea.setAlpha(80);
		this._paintPrecision=new Paint(Paint.ANTI_ALIAS_FLAG);
		this._paintPrecision.setColor(Color.CYAN);
		this._paintPrecision.setAlpha(40);
		midPoints=new ArrayList<Point>();

	}
	
	//===============================================================
	public void Reset()
	//===============================================================
	{
        this.points = new ArrayList<PositionRead>();

	}
	
	//===============================================================
	public RectF getScrollRect()
	//===============================================================
	{
		return this.mBitmapRect;
	}
	
	//===============================================================
	public void addMidPoint(Point p)
	//===============================================================
	{
		this.midPoints.add(p);
	}
	
	//===============================================================
	public void setScaleFactor(float scale)
	//===============================================================
	{
		if(scale<1)
			scale=1;
	   this.scaleFactor=scale;
	}
	
	//===============================================================
	public void setUserPoint(Point nuevo)
	//==============================================================
	{
			this.userPosition= new Point(nuevo.x,nuevo.y-this.CIRCLE_RADIUS);
	}
		
	//===============================================================
	public void addPoint(PointF nuevo,long time)
	//==============================================================
	{
		this.points.add(new PositionRead(new PointF(nuevo.x,nuevo.y-this.CIRCLE_RADIUS),time));
	}
	
	//===============================================================
	public boolean onTouchSuper( MotionEvent event ) 
	//===============================================================
	{
		return super.onTouchEvent(event);
		
	}
	//===============================================================
    public void setPinPosition(Point pos)
	//===============================================================
	{
    	this.pinPosition=pos;
	}
    
  //===============================================================
    public Point getPinPosition()
	//===============================================================
	{
    	return this.pinPosition;
	}
    
	//===============================================================
	public void setPinBitmap(Bitmap pin)
	//===============================================================
	{
		if(pin!=null) this.bluePin=pin;		
	}
	
	//===============================================================
	public List<PositionRead> getPoints()
	//===============================================================
	{
		return this.points;
	}
	
	//===============================================================
	protected void onDraw(Canvas canvas) 
	//===============================================================
	{
		super.onDraw(canvas);
		
		for(int i=0;i<this.points.size()-1;i++)
		{
			PointF first = PositionRead.MapToScreen(this.points.get(i).getPosition(),this.getScale(),this.getScrollRect(),scaleFactor);
			PointF last  = PositionRead.MapToScreen(this.points.get(i+1).getPosition(),this.getScale(),this.getScrollRect(),scaleFactor);
			
			canvas.drawLine(first.x, first.y,last.x, last.y, this._paintLine);
		}
		
		for(PositionRead p:this.points)
		{
			PointF pt = PositionRead.MapToScreen(p.getPosition(),this.getScale(),this.getScrollRect(),scaleFactor);
			canvas.drawCircle(pt.x, pt.y, this.CIRCLE_RADIUS, this._paint);
		}
		
		if(this.userPosition!=null)
		{
			Point upt = PositionRead.MapToScreen(userPosition,this.getScale(),this.getScrollRect(),scaleFactor);
			canvas.drawCircle(upt.x, upt.y, this.CIRCLE_RADIUS, this._paint);
			canvas.drawCircle(upt.x, upt.y, this.CIRCLE_RADIUS*8, this._paintPrecision);
		}
		
		for(Point p:this.midPoints)
		{
			Point pt = PositionRead.MapToScreen(p,this.getScale(),this.getScrollRect(),scaleFactor);
			canvas.drawCircle(pt.x, pt.y, this.POINT_AREA*this.getScale(), this._paintArea);
			canvas.drawCircle(pt.x, pt.y, this.CIRCLE_RADIUS-2, this._paintMidPoints);
		}
		
		
		if(this.bluePin!=null) 
		{
			canvas.drawBitmap(this.bluePin, pinPosition.x -this.bluePin.getWidth()/2, pinPosition.y-this.bluePin.getHeight(), null);
		}
	}
}
